@@ -5,10 +5,10 @@ use strict;
 no strict 'refs';
 use warnings;
 
+use base qw( WWW::Shorten::generic );
 our @EXPORT = qw(makeashorterlink makealongerlink);
-our ($VERSION) = q$Revision: 1.3 $ =~ /^ Revision: \s+ (\S+) \s+ $/x;
+our ($VERSION) = q$Revision: 1.5 $ =~ /^ Revision: \s+ (\S+) \s+ $/x;
 
-use LWP;
 use Carp;
 
 my $style;
@@ -32,20 +32,16 @@ sub import
 }
 
 # Preloaded methods go here.
-sub makeashorterlink ($)
+sub makeashorterlink ($;@)
 {
     my $url = shift or croak 'No URL passed to makeashorterlink';
-    my $ua = LWP::UserAgent->new;
-    return "WWW::Shorten::${style}::makeashorterlink"->($url, $ua);
+    return "WWW::Shorten::${style}::makeashorterlink"->($url, @_);
 }
 
 sub makealongerlink ($) {
     my $code = shift 
 	or croak 'No key / URL passed to makealongerlink';
-    my $ua = LWP::UserAgent->new(
-	requests_redirectable => [],
-    );
-    return "WWW::Shorten::${style}::makealongerlink"->($code, $ua);
+    return "WWW::Shorten::${style}::makealongerlink"->($code);
 }
 
 1;
@@ -60,13 +56,24 @@ WWW::Shorten - Abstract interface to URL shortening sites.
 =head1 SYNOPSIS
 
   use WWW::Shorten 'MakeAShorterLink';
+  use WWW::Shorten 'NotLong';
+  use WWW::Shorten 'QuickOnes';
   use WWW::Shorten 'Shorl';
+  use WWW::Shorten 'SnipURL';
   use WWW::Shorten 'TinyURL';
 
+  # Individual modules have have their
+  # own syntactic varations.
+
+  # See the documentation for the particular
+  # module you intend to use for details, trips
+  # and traps.
+
   $short_url = makeashorterlink($long_url);
 
   $long_url  = makealongerlink($short_url);
 
+
 =head1 DESCRIPTION
 
 A Perl interface to URL shortening sites. These sites maintain
